# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v1/jobs.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v1/jobs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%insightproto/proto/jobs/v1/jobs.proto\x12\x1ainsightproto.proto.jobs.v1\x1a)insightproto/proto/common/v1/common.proto\"\xd4\x01\n\nJobMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12;\n\naether_job\x18\x03 \x01(\x0b\x32%.insightproto.proto.jobs.v1.AetherJobH\x00\x12=\n\x0binsight_job\x18\x04 \x01(\x0b\x32&.insightproto.proto.jobs.v1.InsightJobH\x00\x42\x05\n\x03job\"\xa8\x02\n\tAetherJob\x12\n\n\x02id\x18\x01 \x01(\t\x12<\n\x07project\x18\x02 \x01(\x0b\x32+.insightproto.proto.jobs.v1.ProviderProject\x12\x15\n\rOperationType\x18\x03 \x01(\t\x12\x14\n\x07IssueId\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0c\x44iscussionId\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0eMergeRequestId\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05JobId\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06NoteId\x18\x08 \x01(\tH\x04\x88\x01\x01\x42\n\n\x08_IssueIdB\x0f\n\r_DiscussionIdB\x11\n\x0f_MergeRequestIdB\x08\n\x06_JobIdB\t\n\x07_NoteId\"c\n\x0fProviderProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x08provider\x18\x03 \x01(\x0b\x32$.insightproto.proto.jobs.v1.Provider\"&\n\x08Provider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\"N\n\nInsightJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x07trigger\x18\x02 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\"M\n\x07Trigger\x12\x34\n\x06source\x18\x01 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\x0c\n\x04text\x18\x02 \x01(\tB/Z-github.com/opentrace/insight-proto-go/jobs/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v1.jobs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v1'
  _globals['_JOBMESSAGE']._serialized_start=113
  _globals['_JOBMESSAGE']._serialized_end=325
  _globals['_AETHERJOB']._serialized_start=328
  _globals['_AETHERJOB']._serialized_end=624
  _globals['_PROVIDERPROJECT']._serialized_start=626
  _globals['_PROVIDERPROJECT']._serialized_end=725
  _globals['_PROVIDER']._serialized_start=727
  _globals['_PROVIDER']._serialized_end=765
  _globals['_INSIGHTJOB']._serialized_start=767
  _globals['_INSIGHTJOB']._serialized_end=845
  _globals['_TRIGGER']._serialized_start=847
  _globals['_TRIGGER']._serialized_end=924
# @@protoc_insertion_point(module_scope)
