# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/results.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/results.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+insightproto/proto/results/v1/results.proto\x12\x1dinsightproto.proto.results.v1\x1a)insightproto/proto/common/v1/common.proto\"\xc7\x02\n\x13InvestigationResult\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12H\n\x10\x61lert_extraction\x18\x02 \x01(\x0b\x32..insightproto.proto.results.v1.AlertExtraction\x12>\n\x08timeline\x18\x03 \x03(\x0b\x32,.insightproto.proto.results.v1.TimelineEvent\x12\x12\n\nchecks_run\x18\x04 \x03(\t\x12=\n\nhypotheses\x18\x05 \x03(\x0b\x32).insightproto.proto.results.v1.Hypothesis\x12\x1a\n\x12primary_hypothesis\x18\x06 \x01(\t\"C\n\x0f\x41lertExtraction\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"{\n\rTimelineEvent\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x36\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32(.insightproto.proto.results.v1.EventData\"\x9b\x04\n\tEventData\x12\x15\n\x08username\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tsource_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x61\x63tion\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07success\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x15\n\x08hostname\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0cprocess_name\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x10\n\x03pid\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0c\x63ommand_line\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x11\n\x04user\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0e\x64\x65stination_ip\x18\n \x01(\tH\t\x88\x01\x01\x12\x15\n\x08protocol\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x1d\n\x10\x64\x65stination_port\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12\x17\n\nbytes_sent\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x14\n\x07\x63ommand\x18\x0e \x01(\tH\r\x88\x01\x01\x42\x0b\n\t_usernameB\x0c\n\n_source_ipB\t\n\x07_actionB\n\n\x08_successB\x0b\n\t_hostnameB\x0f\n\r_process_nameB\x06\n\x04_pidB\x0f\n\r_command_lineB\x07\n\x05_userB\x11\n\x0f_destination_ipB\x0b\n\t_protocolB\x13\n\x11_destination_portB\r\n\x0b_bytes_sentB\n\n\x08_command\"p\n\nHypothesis\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\x1b\n\x13supporting_evidence\x18\x03 \x03(\t\x12\x1c\n\x14timeline_correlation\x18\x04 \x03(\tB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.results_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_INVESTIGATIONRESULT']._serialized_start=122
  _globals['_INVESTIGATIONRESULT']._serialized_end=449
  _globals['_ALERTEXTRACTION']._serialized_start=451
  _globals['_ALERTEXTRACTION']._serialized_end=518
  _globals['_TIMELINEEVENT']._serialized_start=520
  _globals['_TIMELINEEVENT']._serialized_end=643
  _globals['_EVENTDATA']._serialized_start=646
  _globals['_EVENTDATA']._serialized_end=1185
  _globals['_HYPOTHESIS']._serialized_start=1187
  _globals['_HYPOTHESIS']._serialized_end=1299
# @@protoc_insertion_point(module_scope)
